@@ -2,6 +2,7 @@ from django.db import models
 from django.db.models.query import QuerySet
 from django.contrib.contenttypes.models import ContentType
 from django.db.models.loading import get_model
+from .signals import follow_bulk_create, follow_bulk_delete
 
 
 class FollowQuerySet(QuerySet):
@@ -30,6 +31,7 @@ class FollowManager(models.Manager):
                 )
             )
         self.bulk_create(follows)
+        follow_bulk_create.send(sender=self.model, users=users, target=target)
 
     def delete_batch(self, users, target):
         target_content_type = ContentType.objects.get_for_model(target)
@@ -39,6 +41,7 @@ class FollowManager(models.Manager):
             target_content_type=target_content_type,
             target_object_id=target.pk,
         ).delete()
+        follow_bulk_delete.send(sender=self.model, users=users, target=target)
 
     def update_batch(self, users_follow, target):
         Follow = get_model('generic_follow', 'Follow')
